@@ -11,8 +11,7 @@ class Interpreter(object):
   def __init__(self, scope=None):
     """Initialize the Interpreter instance.
 
-    scope is a pxp.scope.ScopeBase instance that will be pushed on top of the interpreter's
-    ScopeStack. Each interpreter instance includes the stdlib.global_scope by default.
+    If scope is present, it will be passed to the push method of the instance's ScopeStack.
     """
     self.scope = ScopeStack(global_scope)
     if scope:
@@ -24,15 +23,21 @@ class Interpreter(object):
 
     source is pxp source text.
     """
-    with self.scope.using(DictScope()):
-      compiler = Compiler(source, self.scope)
-      program = compiler.compile()
+    # Give the compiler all the non-global_scope scopes.
+    compiler = Compiler(source, self.scope.scopes[1:])
+    program = compiler.compile()
     return self.execute(program)
 
+  @staticmethod
+  def get_type(program):
+    """Returns the return type of the return statement of the compiled program."""
+    _, ptype, *_ = program
+    return ptype
+
   def execute(self, program):
     """Execute compiled pxp instructions."""
     with self.scope.using(DictScope()):
-      _, *assignments, (_, return_exp) = program
+      _, ptype, assignments, (_, return_exp) = program
       for assignment in assignments:
         self._assign(assignment)
       return self.resolver.resolve(return_exp)
